import { addDialog } from '@/components/BaseDialog/index';
import UserLoginLogDialog from '@/views/monitor/requestLog/user-login-log-dialog.vue';
import { useRequestLogStore } from '@/store/monitor/requestLog';
import { h, ref } from 'vue';
import { message } from '@/utils/message';
import { $t } from '@/plugins/i18n';
import DeleteBatchDialog from '@/components/Table/DeleteBatchDialog.vue';

export const formRef = ref();
// 删除ids
export const deleteIds = ref([]);
const requestLogStore = useRequestLogStore();

/** 搜索初始化用户登录日志 */
export async function onSearch() {
	requestLogStore.loading = true;
	await requestLogStore.getRequestLogList();
	requestLogStore.loading = false;
}

/**
 * * 查看用户登录日志
 * @param row
 */
export function onView(row: any) {
	addDialog({
		title: `${$t('view')}${$t('userLoginLog')}`,
		width: '30%',
		props: {
			formInline: {
				url: row.url,
				userId: row.userId,
				username: row.username,
				token: row.token,
				ipAddress: row.ipAddress,
				ipRegion: row.ipRegion,
				userAgent: row.userAgent,
				arg: row.arg,
				result: row.result,
				executeTime: row.executeTime,
				xRequestedWith: row.xRequestedWith,
			},
		},
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(UserLoginLogDialog, { ref: formRef }),
		beforeSure: async done => {
			done();
			await onSearch();
		},
	});
}

/** 批量删除 */
export const onDeleteBatch = async () => {
	const ids = deleteIds.value;
	const formDeletedBatchRef = ref();

	addDialog({
		title: $t('deleteBatchTip'),
		width: '30%',
		props: { formInline: { confirmText: '' } },
		draggable: true,
		fullscreenIcon: true,
		closeOnClickModal: false,
		contentRenderer: () => h(DeleteBatchDialog, { ref: formDeletedBatchRef }),
		beforeSure: (done, { options }) => {
			formDeletedBatchRef.value.formDeletedBatchRef.validate(async (valid: any) => {
				if (!valid) return;

				const text = options.props.formInline.confirmText.toLowerCase();
				if (text === 'yes' || text === 'y') {
					// 删除数据
					await requestLogStore.deletedRequestLogByIds(ids);
					await onSearch();

					done();
				} else message($t('deleteBatchTip'), { type: 'warning' });
			});
		},
	});
};
